# eric7.RemoteServerInterface.EricServerDebuggerInterface

Module implementing the file system interface to the eric-ide server.

### Global Attributes

None

### Classes

EricServerDebuggerInterface | Class implementing the file system interface to the eric-ide server.

### Functions

None

## EricServerDebuggerInterface

Class implementing the file system interface to the eric-ide server.

### Signals

debugClientDisconnected(debuggerId:str)
  emitted when a remote debug client did disconnect from the eric-ide server
debugClientResponse(response:str)
  emitted to relay a response of the remote debug client
lastClientExited()
  emitted to indicate that the last debug client of the eric-ide server exited

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

EricServerDebuggerInterface | Constructor
__handleDbgClientDisconnected | Private method to handle a debug client disconnect report of the eric-ide server.
__handleDbgClientResponse | Private method to handle a response from a debug client connected to the eric-ide server.
__handleDbgRequestError | Private method to handle an error reported by the debugger interface of the eric-ide server.
__handleDebuggerReply | Private slot to handle a debugger reply from the eric-ide server.
__handleLastDbgClientExited | Private method to handle a report of the eric-ide server, that the last debug client has disconnected.
__handleMainClientExited | Private method to handle the main client exiting.
__handleStartClientError | Private method to handle an error starting the remote debug client.
callback | Function to handle the server reply
sendClientCommand | Public method to rely a debug client command via the eric-ide server.
startClient | Public method to send a command to start a debug client.
stopClient | Public method to stop the debug client synchronously.

### Static Methods

None

#### EricServerDebuggerInterface (Constructor)

EricServerDebuggerInterface(serverInterface)

Constructor

serverInterface (EricServerInterface)
  reference to the eric-ide server interface

#### EricServerDebuggerInterface.__handleDbgClientDisconnected

__handleDbgClientDisconnected(params)

Private method to handle a debug client disconnect report of the eric-ide server.

params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.__handleDbgClientResponse

__handleDbgClientResponse(params)

Private method to handle a response from a debug client connected to the eric-ide server.

params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.__handleDbgRequestError

__handleDbgRequestError(params)

Private method to handle an error reported by the debugger interface of the eric-ide server.

params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.__handleDebuggerReply

__handleDebuggerReply(reply, params)

Private slot to handle a debugger reply from the eric-ide server.

reply (str)
  name of the server reply
params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.__handleLastDbgClientExited

__handleLastDbgClientExited(params)

Private method to handle a report of the eric-ide server, that the last debug client has disconnected.

params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.__handleMainClientExited

__handleMainClientExited(params)

Private method to handle the main client exiting.

params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.__handleStartClientError

__handleStartClientError(params)

Private method to handle an error starting the remote debug client.

params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.callback

callback(params)

Function to handle the server reply

reply (str)
  name of the server reply
params (dict)
  dictionary containing the reply data

#### EricServerDebuggerInterface.sendClientCommand

sendClientCommand(debuggerId, jsonCommand)

Public method to rely a debug client command via the eric-ide server.

debuggerId (str)
  id of the debug client to send the command to
jsonCommand (str)
  JSON encoded command dictionary to be relayed

#### EricServerDebuggerInterface.startClient

startClient(interpreter, originalPathString, args, workingDir="")

Public method to send a command to start a debug client.

interpreter (str)
  path of the remote interpreter to be used
originalPathString (str)
  original PATH environment variable
args (list of str)
  list of command line parameters for the debug client
workingDir (str (optional))
  directory to start the debugger client in (defaults to "")

#### EricServerDebuggerInterface.stopClient

stopClient()

Public method to stop the debug client synchronously.

Up